@@ -22,11 +22,17 @@ Usage::
     describe_ml_models_paginator: DescribeMLModelsPaginator = client.get_paginator("describe_ml_models")
     ```
 """
-import sys
 from typing import Iterator
 
 from botocore.paginate import Paginator as Boto3Paginator
 
+from mypy_boto3_machinelearning.literals import (
+    BatchPredictionFilterVariable,
+    DataSourceFilterVariable,
+    EvaluationFilterVariable,
+    MLModelFilterVariable,
+    SortOrder,
+)
 from mypy_boto3_machinelearning.type_defs import (
     DescribeBatchPredictionsOutputTypeDef,
     DescribeDataSourcesOutputTypeDef,
@@ -35,12 +41,6 @@ from mypy_boto3_machinelearning.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "DescribeBatchPredictionsPaginator",
     "DescribeDataSourcesPaginator",
@@ -51,21 +51,12 @@ __all__ = (
 
 class DescribeBatchPredictionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeBatchPredictions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)
+    [Paginator.DescribeBatchPredictions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)
     """
 
     def paginate(
         self,
-        FilterVariable: Literal[
-            "CreatedAt",
-            "LastUpdatedAt",
-            "Status",
-            "Name",
-            "IAMUser",
-            "MLModelId",
-            "DataSourceId",
-            "DataURI",
-        ] = None,
+        FilterVariable: BatchPredictionFilterVariable = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -73,24 +64,22 @@ class DescribeBatchPredictionsPaginator(Boto3Paginator):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: Literal["asc", "dsc"] = None,
+        SortOrder: SortOrder = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeBatchPredictionsOutputTypeDef]:
         """
-        [DescribeBatchPredictions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions.paginate)
+        [DescribeBatchPredictions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions.paginate)
         """
 
 
 class DescribeDataSourcesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDataSources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)
+    [Paginator.DescribeDataSources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)
     """
 
     def paginate(
         self,
-        FilterVariable: Literal[
-            "CreatedAt", "LastUpdatedAt", "Status", "Name", "DataLocationS3", "IAMUser"
-        ] = None,
+        FilterVariable: DataSourceFilterVariable = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -98,31 +87,22 @@ class DescribeDataSourcesPaginator(Boto3Paginator):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: Literal["asc", "dsc"] = None,
+        SortOrder: SortOrder = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeDataSourcesOutputTypeDef]:
         """
-        [DescribeDataSources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources.paginate)
+        [DescribeDataSources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources.paginate)
         """
 
 
 class DescribeEvaluationsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEvaluations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)
+    [Paginator.DescribeEvaluations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)
     """
 
     def paginate(
         self,
-        FilterVariable: Literal[
-            "CreatedAt",
-            "LastUpdatedAt",
-            "Status",
-            "Name",
-            "IAMUser",
-            "MLModelId",
-            "DataSourceId",
-            "DataURI",
-        ] = None,
+        FilterVariable: EvaluationFilterVariable = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -130,33 +110,22 @@ class DescribeEvaluationsPaginator(Boto3Paginator):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: Literal["asc", "dsc"] = None,
+        SortOrder: SortOrder = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeEvaluationsOutputTypeDef]:
         """
-        [DescribeEvaluations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations.paginate)
+        [DescribeEvaluations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations.paginate)
         """
 
 
 class DescribeMLModelsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeMLModels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)
+    [Paginator.DescribeMLModels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)
     """
 
     def paginate(
         self,
-        FilterVariable: Literal[
-            "CreatedAt",
-            "LastUpdatedAt",
-            "Status",
-            "Name",
-            "IAMUser",
-            "TrainingDataSourceId",
-            "RealtimeEndpointStatus",
-            "MLModelType",
-            "Algorithm",
-            "TrainingDataURI",
-        ] = None,
+        FilterVariable: MLModelFilterVariable = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -164,9 +133,9 @@ class DescribeMLModelsPaginator(Boto3Paginator):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: Literal["asc", "dsc"] = None,
+        SortOrder: SortOrder = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeMLModelsOutputTypeDef]:
         """
-        [DescribeMLModels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels.paginate)
+        [DescribeMLModels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels.paginate)
         """
