@@ -13,10 +13,15 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_machinelearning.literals import (
+    Algorithm,
+    DetailsAttributes,
+    EntityStatus,
+    MLModelType,
+    RealtimeEndpointStatus,
+    TaggableResourceType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -85,7 +90,7 @@ BatchPredictionTypeDef = TypedDict(
         "CreatedAt": datetime,
         "LastUpdatedAt": datetime,
         "Name": str,
-        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
+        "Status": EntityStatus,
         "OutputUri": str,
         "Message": str,
         "ComputeTime": int,
@@ -109,7 +114,7 @@ DataSourceTypeDef = TypedDict(
         "DataSizeInBytes": int,
         "NumberOfFiles": int,
         "Name": str,
-        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
+        "Status": EntityStatus,
         "Message": str,
         "RedshiftMetadata": "RedshiftMetadataTypeDef",
         "RDSMetadata": "RDSMetadataTypeDef",
@@ -133,7 +138,7 @@ EvaluationTypeDef = TypedDict(
         "CreatedAt": datetime,
         "LastUpdatedAt": datetime,
         "Name": str,
-        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
+        "Status": EntityStatus,
         "PerformanceMetrics": "PerformanceMetricsTypeDef",
         "Message": str,
         "ComputeTime": int,
@@ -152,13 +157,13 @@ MLModelTypeDef = TypedDict(
         "CreatedAt": datetime,
         "LastUpdatedAt": datetime,
         "Name": str,
-        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
+        "Status": EntityStatus,
         "SizeInBytes": int,
         "EndpointInfo": "RealtimeEndpointInfoTypeDef",
         "TrainingParameters": Dict[str, str],
         "InputDataLocationS3": str,
-        "Algorithm": Literal["sgd"],
-        "MLModelType": Literal["REGRESSION", "BINARY", "MULTICLASS"],
+        "Algorithm": Algorithm,
+        "MLModelType": MLModelType,
         "ScoreThreshold": float,
         "ScoreThresholdLastUpdatedAt": datetime,
         "Message": str,
@@ -179,7 +184,7 @@ PredictionTypeDef = TypedDict(
         "predictedLabel": str,
         "predictedValue": float,
         "predictedScores": Dict[str, float],
-        "details": Dict[Literal["PredictiveModelType", "Algorithm"], str],
+        "details": Dict[DetailsAttributes, str],
     },
     total=False,
 )
@@ -211,7 +216,7 @@ RealtimeEndpointInfoTypeDef = TypedDict(
         "PeakRequestsPerSecond": int,
         "CreatedAt": datetime,
         "EndpointUrl": str,
-        "EndpointStatus": Literal["NONE", "READY", "UPDATING", "FAILED"],
+        "EndpointStatus": RealtimeEndpointStatus,
     },
     total=False,
 )
@@ -247,7 +252,7 @@ AddTagsOutputTypeDef = TypedDict(
     "AddTagsOutputTypeDef",
     {
         "ResourceId": str,
-        "ResourceType": Literal["BatchPrediction", "DataSource", "Evaluation", "MLModel"],
+        "ResourceType": TaggableResourceType,
         "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
@@ -337,7 +342,7 @@ DeleteTagsOutputTypeDef = TypedDict(
     "DeleteTagsOutputTypeDef",
     {
         "ResourceId": str,
-        "ResourceType": Literal["BatchPrediction", "DataSource", "Evaluation", "MLModel"],
+        "ResourceType": TaggableResourceType,
         "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
@@ -383,7 +388,7 @@ DescribeTagsOutputTypeDef = TypedDict(
     "DescribeTagsOutputTypeDef",
     {
         "ResourceId": str,
-        "ResourceType": Literal["BatchPrediction", "DataSource", "Evaluation", "MLModel"],
+        "ResourceType": TaggableResourceType,
         "Tags": List["TagTypeDef"],
         "ResponseMetadata": "ResponseMetadata",
     },
@@ -401,7 +406,7 @@ GetBatchPredictionOutputTypeDef = TypedDict(
         "CreatedAt": datetime,
         "LastUpdatedAt": datetime,
         "Name": str,
-        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
+        "Status": EntityStatus,
         "OutputUri": str,
         "LogUri": str,
         "Message": str,
@@ -427,7 +432,7 @@ GetDataSourceOutputTypeDef = TypedDict(
         "DataSizeInBytes": int,
         "NumberOfFiles": int,
         "Name": str,
-        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
+        "Status": EntityStatus,
         "LogUri": str,
         "Message": str,
         "RedshiftMetadata": "RedshiftMetadataTypeDef",
@@ -454,7 +459,7 @@ GetEvaluationOutputTypeDef = TypedDict(
         "CreatedAt": datetime,
         "LastUpdatedAt": datetime,
         "Name": str,
-        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
+        "Status": EntityStatus,
         "PerformanceMetrics": "PerformanceMetricsTypeDef",
         "LogUri": str,
         "Message": str,
@@ -475,12 +480,12 @@ GetMLModelOutputTypeDef = TypedDict(
         "CreatedAt": datetime,
         "LastUpdatedAt": datetime,
         "Name": str,
-        "Status": Literal["PENDING", "INPROGRESS", "FAILED", "COMPLETED", "DELETED"],
+        "Status": EntityStatus,
         "SizeInBytes": int,
         "EndpointInfo": "RealtimeEndpointInfoTypeDef",
         "TrainingParameters": Dict[str, str],
         "InputDataLocationS3": str,
-        "MLModelType": Literal["REGRESSION", "BINARY", "MULTICLASS"],
+        "MLModelType": MLModelType,
         "ScoreThreshold": float,
         "ScoreThresholdLastUpdatedAt": datetime,
         "LogUri": str,
