@@ -22,18 +22,17 @@ Usage::
     ml_model_available_waiter: MLModelAvailableWaiter = client.get_waiter("ml_model_available")
     ```
 """
-import sys
-
 from botocore.waiter import Waiter as Boto3Waiter
 
+from mypy_boto3_machinelearning.literals import (
+    BatchPredictionFilterVariable,
+    DataSourceFilterVariable,
+    EvaluationFilterVariable,
+    MLModelFilterVariable,
+    SortOrder,
+)
 from mypy_boto3_machinelearning.type_defs import WaiterConfigTypeDef
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "BatchPredictionAvailableWaiter",
     "DataSourceAvailableWaiter",
@@ -44,21 +43,12 @@ __all__ = (
 
 class BatchPredictionAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.BatchPredictionAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable)
+    [Waiter.BatchPredictionAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable)
     """
 
     def wait(
         self,
-        FilterVariable: Literal[
-            "CreatedAt",
-            "LastUpdatedAt",
-            "Status",
-            "Name",
-            "IAMUser",
-            "MLModelId",
-            "DataSourceId",
-            "DataURI",
-        ] = None,
+        FilterVariable: BatchPredictionFilterVariable = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -66,26 +56,24 @@ class BatchPredictionAvailableWaiter(Boto3Waiter):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: Literal["asc", "dsc"] = None,
+        SortOrder: SortOrder = None,
         NextToken: str = None,
         Limit: int = None,
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [BatchPredictionAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable.wait)
+        [BatchPredictionAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable.wait)
         """
 
 
 class DataSourceAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.DataSourceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable)
+    [Waiter.DataSourceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable)
     """
 
     def wait(
         self,
-        FilterVariable: Literal[
-            "CreatedAt", "LastUpdatedAt", "Status", "Name", "DataLocationS3", "IAMUser"
-        ] = None,
+        FilterVariable: DataSourceFilterVariable = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -93,33 +81,24 @@ class DataSourceAvailableWaiter(Boto3Waiter):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: Literal["asc", "dsc"] = None,
+        SortOrder: SortOrder = None,
         NextToken: str = None,
         Limit: int = None,
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [DataSourceAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable.wait)
+        [DataSourceAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable.wait)
         """
 
 
 class EvaluationAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.EvaluationAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable)
+    [Waiter.EvaluationAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable)
     """
 
     def wait(
         self,
-        FilterVariable: Literal[
-            "CreatedAt",
-            "LastUpdatedAt",
-            "Status",
-            "Name",
-            "IAMUser",
-            "MLModelId",
-            "DataSourceId",
-            "DataURI",
-        ] = None,
+        FilterVariable: EvaluationFilterVariable = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -127,35 +106,24 @@ class EvaluationAvailableWaiter(Boto3Waiter):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: Literal["asc", "dsc"] = None,
+        SortOrder: SortOrder = None,
         NextToken: str = None,
         Limit: int = None,
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [EvaluationAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable.wait)
+        [EvaluationAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable.wait)
         """
 
 
 class MLModelAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.MLModelAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable)
+    [Waiter.MLModelAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable)
     """
 
     def wait(
         self,
-        FilterVariable: Literal[
-            "CreatedAt",
-            "LastUpdatedAt",
-            "Status",
-            "Name",
-            "IAMUser",
-            "TrainingDataSourceId",
-            "RealtimeEndpointStatus",
-            "MLModelType",
-            "Algorithm",
-            "TrainingDataURI",
-        ] = None,
+        FilterVariable: MLModelFilterVariable = None,
         EQ: str = None,
         GT: str = None,
         LT: str = None,
@@ -163,11 +131,11 @@ class MLModelAvailableWaiter(Boto3Waiter):
         LE: str = None,
         NE: str = None,
         Prefix: str = None,
-        SortOrder: Literal["asc", "dsc"] = None,
+        SortOrder: SortOrder = None,
         NextToken: str = None,
         Limit: int = None,
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [MLModelAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.59/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable.wait)
+        [MLModelAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable.wait)
         """
